/** \file Settings.cpp
*/

/* Copyright (C) 2008-2009 Tomasz Ostrowski <tomasz.o.ostrowski at gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.

 * Miniscope is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#pragma hdrstop

#include <IniFiles.hpp>
#include "Settings.h"

//---------------------------------------------------------------------------

#pragma package(smart_init)

bool Settings::Read(AnsiString asFileName)
{
	TIniFile *ini = NULL;
	try
	{
		ini = new TIniFile(asFileName);
		// main window startup position
		int maxX = GetSystemMetrics(SM_CXSCREEN);
		int maxY = GetSystemMetrics(SM_CYSCREEN);
		iWidth = ini->ReadInteger("GUI", "AppWidth", 550);
		iHeight = ini->ReadInteger("GUI", "AppHeight", 400);
		if (iWidth < 250 || iWidth > maxX + 20)
		{
			iWidth = 250;
		}
		if (iHeight < 200 || iHeight > maxY + 20)
		{
			iHeight = 200;
		}
		iPosX = ini->ReadInteger("GUI", "AppPositionX", 30);
		iPosY = ini->ReadInteger("GUI", "AppPositionY", 30);
		if (iPosX < 0)
			iPosX = 0;
		if (iPosY < 0)
			iPosY = 0;
		if (iPosX + iWidth > maxX)
			iPosX = maxX - iWidth;
		if (iPosY + iHeight > maxY)
			iPosY = maxY - iHeight;
		bAlwaysOnTop = ini->ReadBool("GUI", "AlwaysOnTop", false);
		bWindowMaximized = ini->ReadBool("GUI", "Maximized", false);
		iMaxUiLogLines = ini->ReadInteger("Application", "MaxUiLogLines", 1000);
		iDisplayRefreshFreq = ini->ReadInteger("Application", "DisplayRefreshFreq", 20);
		//iSendSuffix = ini->ReadInteger("Application", "SendSuffix", SENDSUFFIX_CRLF);
		asInputDeviceDllName = ini->ReadString("Application", "InputDeviceDllName", "");
		asPlotPictureExportDir = ini->ReadString("Application", "PlotPictureExportDir", "");
		asPlotDataExportDir = ini->ReadString("Application", "PlotDataExportDir", "");
		fRecorderInterval = ini->ReadFloat("Recorder", "Interval", 10.0);

		GraphOscilloscope.bGridX = ini->ReadBool("GraphOscilloscope", "GridX", true);
		GraphOscilloscope.bGridY = ini->ReadBool("GraphOscilloscope", "GridY", true);
		GraphOscilloscope.bGridLabels = ini->ReadBool("GraphOscilloscope", "GridLabels", true);
		GraphSpectrum.bGridX = ini->ReadBool("GraphSpectrum", "GridX", true);
		GraphSpectrum.bGridY = ini->ReadBool("GraphSpectrum", "GridY", true);
		GraphSpectrum.bGridLabels = ini->ReadBool("GraphSpectrum", "GridLabels", true);
		GraphRecorder.bGridX = ini->ReadBool("GraphRecorder", "GridX", true);
		GraphRecorder.bGridY = ini->ReadBool("GraphRecorder", "GridY", true);
		GraphRecorder.bGridLabels = ini->ReadBool("GraphRecorder", "GridLabels", true);

		GraphToolboxTransparency = ini->ReadInteger("Graph", "ToolboxTransparency", 255);
		if (GraphToolboxTransparency < 30 || GraphToolboxTransparency > 255)
			GraphToolboxTransparency = 255;		

		Statistics.bVisible = ini->ReadBool("Statistics", "Visible", false);
		Statistics.iPosX = ini->ReadInteger("Statistics", "PosX", 40);
		Statistics.iPosY = ini->ReadInteger("Statistics", "PosY", 40);
		if (Statistics.iPosX < 0)
			Statistics.iPosX = 0;
		if (Statistics.iPosY < 0)
			Statistics.iPosY = 0;
		if (Statistics.iPosX + 40 > maxX)
			Statistics.iPosX = maxX - 40;
		if (Statistics.iPosY + 40 > maxY)
			Statistics.iPosY = maxY - 40;


		delete ini;
	}
	catch (...)
	{
		if (ini)
		{
			delete ini;
		}
		return false;
	}
	return true;
}

bool Settings::Write(AnsiString asFileName)
{
	TIniFile *ini = NULL;
	try
	{
		ini = new TIniFile(asFileName);
		ini->WriteInteger("GUI", "AppWidth", iWidth);
		ini->WriteInteger("GUI", "AppHeight", iHeight);
		ini->WriteInteger("GUI", "AppPositionX", iPosX);
		ini->WriteInteger("GUI", "AppPositionY", iPosY);
		ini->WriteBool("GUI", "AlwaysOnTop", bAlwaysOnTop);
		ini->WriteBool("GUI", "Maximized", bWindowMaximized);	
		ini->WriteInteger("Application", "MaxUiLogLines", iMaxUiLogLines);
		ini->WriteInteger("Application", "DisplayRefreshFreq", iDisplayRefreshFreq);
		ini->WriteString("Application", "InputDeviceDllName", asInputDeviceDllName);
		ini->WriteString("Application", "PlotPictureExportDir", asPlotPictureExportDir);
		ini->WriteString("Application", "PlotDataExportDir", asPlotDataExportDir);
		ini->WriteFloat("Recorder", "Interval", fRecorderInterval);

		ini->WriteBool("GraphOscilloscope", "GridX", GraphOscilloscope.bGridX);
		ini->WriteBool("GraphOscilloscope", "GridY", GraphOscilloscope.bGridY);
		ini->WriteBool("GraphOscilloscope", "GridLabels", GraphOscilloscope.bGridLabels);
		ini->WriteBool("GraphSpectrum", "GridX", GraphSpectrum.bGridX);
		ini->WriteBool("GraphSpectrum", "GridY", GraphSpectrum.bGridY);
		ini->WriteBool("GraphSpectrum", "GridLabels", GraphSpectrum.bGridLabels);
		ini->WriteBool("GraphRecorder", "GridX", GraphRecorder.bGridX);
		ini->WriteBool("GraphRecorder", "GridY", GraphRecorder.bGridY);
		ini->WriteBool("GraphRecorder", "GridLabels", GraphRecorder.bGridLabels);
		
		ini->WriteInteger("Graph", "ToolboxTransparency", GraphToolboxTransparency);

		ini->WriteBool("Statistics", "Visible", Statistics.bVisible);
		ini->WriteInteger("Statistics", "PosX", Statistics.iPosX);
		ini->WriteInteger("Statistics", "PosY", Statistics.iPosY);

		delete ini;
	}
	catch (...)
	{
		if (ini)
		{
			delete ini;
		}
		return false;
	}
	return true;

}
